django-uploader v 0.1 — django-uploader 0.1 documentation

# django-uploader v 0.1

## About

Django Uploader uses jQuery file upload to allow drag-and-drop file upload of any file type in the Django Admin. Third-party applications to write handlers for specific file types, and register them with Django Uploader. When a file of that type is uploaded, it passes the information to the handler so that it can make a new record with that file.

## Contents

- Getting Started
  - Installation
  - Writing an upload handler
  - Adding a thumbnail
  - Registering the handler
- Models